#
# spec file for package python-dkimpy
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
%define commands arcsign arcverify dkimsign dkimverify dknewkey
Name:           python-dkimpy
Version:        1.0.5
Release:        2.1
Summary:        DKIM (DomainKeys Identified Mail)
License:        BSD-2-Clause
URL:            https://launchpad.net/dkimpy
Source:         https://files.pythonhosted.org/packages/source/d/dkimpy/dkimpy-%{version}.tar.gz
Patch0:         no-optional.patch
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-PyNaCl
Requires:       python-authres
Requires:       python-dnspython >= 1.16
Requires:       python-setuptools
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module PyNaCl}
BuildRequires:  %{python_module authres}
BuildRequires:  %{python_module dnspython >= 1.16}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
DKIM (DomainKeys Identified Mail)

%prep
%setup -q -n dkimpy-%{version}
%patch0 -p1

%build
%python_build

%install
%python_install
for c in %{commands}; do
  %python_clone -a %{buildroot}%{_mandir}/man1/$c.1
  %python_clone -a %{buildroot}%{_bindir}/$c
done
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%post
for c in %{commands}; do
  %python_install_alternative $c $c.1
done

%postun
for c in %{commands}; do
  %python_uninstall_alternative $c
done

%files %{python_files}
%doc ChangeLog README.md
%license LICENSE
%python_alternative %{_bindir}/arcsign
%python_alternative %{_bindir}/arcverify
%python_alternative %{_bindir}/dkimsign
%python_alternative %{_bindir}/dkimverify
%python_alternative %{_bindir}/dknewkey
%python_alternative %{_mandir}/man1/arcsign.1%{?ext_man}
%python_alternative %{_mandir}/man1/arcverify.1%{?ext_man}
%python_alternative %{_mandir}/man1/dkimsign.1%{?ext_man}
%python_alternative %{_mandir}/man1/dkimverify.1%{?ext_man}
%python_alternative %{_mandir}/man1/dknewkey.1%{?ext_man}
%{python_sitelib}/*

%changelog
* Sun Jun 18 2023 Andreas Schneider <asn@cryptomilk.org>
- Use sle15_python_module_pythons
* Tue Dec  8 2020 Jiri Slaby <jslaby@suse.cz>
- update to 1.0.5
  - Update dnsplug for DNS Python (dns) 2.0 compatibility (LP: #1888583)
  - Fix @param srv_id typos (LP: #1890532)
  - Correct dkim.verify processing to avoid errors when verifying messages
    with no DKIM signatures
* Tue May 26 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Fri Apr  3 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 1.0.3
  * dknewkey: On posix operating systems set file permissions to 600 for
    ed25519 private key files (as is already done for RSA) (LP: #1857827)
  * Set minimum dnspython version to 1.16 because previous versions can not
    support the timeout parameter (LP: #1856546)
  * Follow CNAMES when looking up key records when using DNS (pydns)
  * Add support for RFC 8460 tlsrpt DKIM signature processing (LP: #1847020)
  * Add async support with aiodns for DKIM verification (ARC not supported)
  * Add new timeout parameter to enable DNS lookup timeouts to be adjusted
  * Add new DKIM.present function to allow applications to test if a DKIM
    signature is present without doing validation (LP: #1851141)
  * Support signature verification with RSAPublicKey formatted keys
    since, although rare, they are RFC 6376 specified (LP: #1851862)
  * Drop usage of pymilter Milter.dns in dnsplug since it doesn't support
    having a timeout passed to it
  * Catch binascii related key format errors (LP: #1854477)
  * Ignore unknown service types in key records (LP: #1847020)
  * Add LICENSE to MANIFEST.in so it is included in the tarball
- Drop shipped LICENSE file
- Reapplied patch no-optional.patch
* Mon Dec  2 2019 pgajdos@suse.com
- call spec-cleaner
* Wed Sep 25 2019 Tomáš Chvátal <tchvatal@suse.com>
- Drop the pynacl workaround as fix was submitted to the TW
  integration
* Wed Sep 25 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to not optionaly import stuff, as it hides import
  errors and we want those to be hard enabled anyway:
  * no-optional.patch
* Wed Sep 25 2019 pgajdos@suse.com
- initial version 0.9.3, required by pyton-authheaders [SLE-7686]
